@@ -229,7 +229,7 @@ sampleN.TOST <- function(alpha=0.05, targetpower=0.8, logscale=TRUE, theta0,
     if (details) cat( n," ", formatC(pow, digits=6, format="f"),"\n")
     if (iter>imax) break 
   }
-  
+  #browser()
   # for very large n the search usually fails, but doesn't matter
   nlast <- n
   if (up & pow<targetpower & n<10000) {
@@ -249,12 +249,12 @@ sampleN.TOST <- function(alpha=0.05, targetpower=0.8, logscale=TRUE, theta0,
   }
   if (details && print) {
     if (method=="exact" || method=="owenq") 
-      cat("\nExact power calculation with\nOwen's Q functions.")
+      cat("\nExact power calculation with\nOwen's Q functions.\n")
     if (method=="mvt") 
-      cat("\nExact power calculation with\nbivariate non-central t-distribution.")
+      cat("\nExact power calculation with\nbivariate non-central t-distribution.\n")
   }
   # always print if approx.
-  if (print && (method!="exact" || method!="mvt")){
+  if (print & (method!="exact" & method!="mvt")){
     approx <- switch(
       method,
       nct="Approximate power calculation with\nnon-central t-distribution.",
