@@ -18,7 +18,7 @@
 sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1, 
                            theta2, CV, design=c("2x3x3", "2x2x4", "2x2x3"), 
                            regulator=c("EMA", "ANVISA", "FDA"), nsims=1E5,
-                           nstart, print=TRUE, details=TRUE, setseed=TRUE)
+                           nstart, imax=100, print=TRUE, details=TRUE, setseed=TRUE)
 {
   if (missing(theta1) & missing(theta2)) theta1 <- 0.8
   if (missing(theta2)) theta2=1/theta1
@@ -146,7 +146,8 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     # cat(n01,n02,"\n")
     n <- max(c(n01,n02))
   } else n <- seqs*round(nstart/seqs)           
-  # iterate until pwr>=targetpower
+  nmin <- 6
+  if (n<nmin) n <- nmin
   # we are simulating for balanced designs
   C2 <- bk/n
   # sd of the sample mean T-R (point estimator)
@@ -154,7 +155,7 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
   df   <- eval(dfe)
   dfRR <- eval(dfRRe)
   dfTT <- dfRR
-  
+
   if(setseed) set.seed(123456)
   p <- .power.scABEL(mlog, sdm, C2, Emse, cvec, df, s2wR, dfRR, s2wT, dfTT,
                      design, nsims, CVswitch, r_const, CVcap, 
@@ -168,8 +169,7 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     # this is for cases with only one step-down and than step up
     if (pwr<=targetpower) cat( n," ", formatC(pwr, digits=pd, format="f"),"\n")
   }
-  iter <- 0; imax=100
-  nmin <- 6
+  iter <- 0
   # iter>100 is emergency brake
   # --- loop until power <= target power, step-down
   down <- FALSE
@@ -217,13 +217,13 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     if (details) cat( n," ", formatC(pwr, digits=pd, format="f"),"\n")
     if (iter>imax) break 
   }
-  
+
   nlast <- n
   if (up & pwr<targetpower) {
     n <- NA
     if (details) cat("Sample size search failed!\n")
   }
-  if (down & pwr>targetpower) {
+  if (down & pwr>targetpower & n != nmin) {
     n <- NA
     if (details) cat("Sample size search failed!\n")
   }
